@@ -10,7 +10,7 @@ from rdr import *
 @click.option('-t', '--type', default='dendrogram', type=click.Choice( [ 'cube', 'dendrogram' ] ), help='output in a more human-readable form')
 def cluster( carrel, type ) :
 
-	"""Apply dimension reduction to <carrel> and visualize the result
+	"""Apply dimension reduction to <carrel> and visualize the result.
 	
 	This is useful to determine how holistic a study carrel is.
 	
