@@ -10,7 +10,7 @@ from rdr import *
 @click.argument( 'carrel', metavar='<carrel>' )
 def read( carrel, location ) :
 
-	"""Open <carrel> in your Web browser
+	"""Open <carrel> in your Web browser.
 	
 	Use this subcommand to peruse the narrative texts and interactive reports found in every study carrel; use this command to become familiar with the content of <carrel>.
 	
